const String ref = '\$ref';
const String model_with_parameters_v3 = '''
{
 "components": {
    "schemas": {
      "SomeEnumModel" : {
        "enum" : ["one", "two"]
      },
      "trickPlayControl": {
      "type": "array",
      "items": {
        "type": "string",
        "enum": [
          "disallowFastForward",
          "disallowPause",
          "disallowPlay",
          "disallowRewind",
          "disallowSkipForward",
          "disallowSkipBackward",
          "adRestrictionOnly"
        ]
      }
    },
      "AuthorizationDetails": {
        "type": "object",
        "properties": {
          "state": {
            "type": "string",
            "format": "uuid",
            "description": "Opaque value generated. The state will be echoed back in the token response, therefore state needs to be maintained between the request and the response.",
            "example": "00001-00002-00003-00004"
          },
          "authorizationUri": {
            "type": "string",
            "format": "uri",
            "description": "URI to follow for authorization",
            "example": "https://sso.service.some.country/oidc/authorize?response_type=code&state=00001-00002-00003-00004&nonce=54345345-345345345-345345345-435345&client_id=some-client-id&redirect_uri=https%3A%2F%2Fsome-success-uri.com%2Fen_gb%2Flogin_success"
          },
          "enumValue": {
            "type": "enum",
            "enum": ["one", "two"]
          },
          "redirectUri": {
            "type": "string",
            "format": "uri",
            "description": "Redirect URI used after successful authentication",
            "example": "https%3A%2F%2Fsome-success-uri.com%2Fen_gb%2Flogin_success"
          },
          "logoutUri": {
            "type": "string",
            "format": "uri",
            "description": "URI to follow to logout"
          },
          "validityToken": {
            "type": "string",
            "description": "The validity token will contain the payload of the generated nonce and state value.",
            "example": ""
          }
        }
      },
      "CompleteAuthorizationRequest": {
        "type": "object",
        "properties": {
          "code": {
            "type": "string",
            "description": "Code value obtained for SSO authorization service"
          },
          "state": {
            "type": "string",
            "format": "uuid",
            "description": "State value obtained previously",
            "example": "00001-00002-00003-00004"
          },
          "validityToken": {
            "type": "string",
            "description": "The validity token obtained previously",
            "example": ""
          }
        }
      },
      "TokensResponse": {
        "type": "object",
        "properties": {
          "token_type": {
            "type": "string",
            "enum": [
              "bearer"
            ]
          },
          "access_token": {
            "$ref": "#/components/schemas/SvcAccessToken"
          },
          "refresh_token": {
            "$ref": "#/components/schemas/SvcRefreshToken"
          },
          "expires_in": {
            "type": "integer",
            "description": "access token expiration in seconds"
          },
          "username": {
            "type": "string",
            "description": "username of authenticated client"
          },
          "givenName": {
            "type": "string",
            "description": "first name"
          },
          "familyName": {
            "type": "string",
            "description": "family name"
          }
        }
      },
      "RefreshAuthorizationRequest": {
        "type": "object",
        "properties": {
          "svcRefreshToken": {
            "$ref": "#/components/schemas/SvcRefreshToken"
          }
        }
      },
      "DeleteAuthorizationRequest": {
        "type": "object",
        "properties": {
          "svcRefreshToken": {
            "$ref": "#/components/schemas/SvcRefreshToken"
          }
        }
      },
      "SvcRefreshToken": {
        "type": "string",
        "description": "Valid service refresh token"
      },
      "SvcAccessToken": {
        "type": "string",
        "description": "jwt service access token used as ACCESS_TOKEN with calls to services"
      }
    }
  }
}
''';

const String model_with_parameters_v2 = '''
{
  "definitions": {
    "trickPlayControl": {
      "type": "array",
      "items": {
        "type": "string",
        "enum": [
          "disallowFastForward",
          "disallowPause",
          "disallowPlay",
          "disallowRewind",
          "disallowSkipForward",
          "disallowSkipBackward",
          "adRestrictionOnly"
        ]
      }
    },
    "ActiveOrderAndListSummary": {
      "type": "object",
      "required": [
        "closingTime",
        "id",
        "shoppingType",
        "slotReservationHours",
        "state"
      ],
      "properties": {
        "closingTime": {
          "type": "string",
          "format": "date-time"
        },
        "deliveryDate": {
          "originalRef": "DeliveryDto",
          "\$ref": "#/definitions/DeliveryDto"
        },
        "id": {
          "type": "integer",
          "format": "int64"
        },
        "lastSyncedDate": {
          "type": "string",
          "format": "date-time"
        },
        "enumValue": {
            "type": "enum",
            "enum": ["one", "two"]
          },
        "orderLastChangedTime": {
          "type": "string",
          "format": "date-time"
        },
        "orderedProducts": {
          "type": "array",
          "items": {
            "originalRef": "OrderedProductCard",
            "\$ref": "#/definitions/OrderedProductCard"
          }
        },
        "price": {
          "originalRef": "PriceDto",
          "\$ref": "#/definitions/PriceDto"
        },
        "shoppingListItems": {
          "type": "array",
          "items": {
            "originalRef": "Item",
            "\$ref": "#/definitions/Item"
          }
        },
        "shoppingType": {
          "type": "string",
          "enum": [
            "UNKNOWN",
            "PHYSICAL_STORE",
            "DELIVERY",
            "PICKUP_DELIVERY",
            "DELIVERY_POINT",
            "PICKUP",
            "IN_STORE_PICK",
            "SPECIALS_ONLY"
          ]
        },
        "slotReservationHours": {
          "type": "number",
          "format": "double"
        },
        "state": {
          "type": "string",
          "enum": [
            "CONFIRMED",
            "REOPENED",
            "IN_PREPARATION",
            "UNCONFIRMED",
            "DELIVERED",
            "CANCELLED",
            "PLANNED_FOR_DELIVERY",
            "OUT_FOR_DELIVERY",
            "UNKNOWN"
          ]
        }
      },
      "title": "ActiveOrderAndListSummary"
    }
  }
}
''';

const String request_with_header = '''
{
  "paths": {
    "/v2/order/summaries": {
      "get": {
        "tags": [
          "appie-order-controller-v-2"
        ],
        "summary": "Get order summaries",
        "operationId": "retrieveOrderSummariesUsingGET",
        "produces": [
          "*/*"
        ],
        "parameters": [
          {
            "name": "x-application",
            "in": "header",
            "description": "x-application",
            "required": true,
            "type": "string"
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "array",
              "items": {
                "originalRef": "OrderSummary",
                "\$ref": "#/definitions/OrderSummary"
              }
            }
          },
          "401": {
            "description": "Unauthorized"
          },
          "403": {
            "description": "Forbidden"
          },
          "404": {
            "description": "Not Found"
          }
        },
        "security": [
          {
            "apiKey": []
          }
        ],
        "deprecated": false
      }
    }
  }
}
''';

const String request_with_enum_in_parameter = '''
{
  "paths": {
    "/v3/order/{orderId}/state": {
      "put": {
        "tags": [
          "appie-order-controller-v-3"
        ],
        "summary": "Update state of an order.",
        "operationId": "changeOrderStateUsingPUT",
        "consumes": [
          "application/json"
        ],
        "produces": [
          "*/*"
        ],
        "parameters": [
          {
            "name": "orderId",
            "in": "path",
            "description": "Id of the order",
            "required": false,
            "type": "integer",
            "format": "int64"
          },
          {
            "in": "body",
            "name": "orderStateRequest",
            "description": "Order state",
            "required": false,
            "schema": {
              "type": "string",
              "enum": [
                "SUBMITTED",
                "CANCELLED",
                "REOPENED",
                "RESET"
              ]
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "object"
            }
          },
          "201": {
            "description": "Created"
          },
          "401": {
            "description": "Unauthorized"
          },
          "403": {
            "description": "Forbidden"
          },
          "404": {
            "description": "Not Found"
          }
        },
        "security": [
          {
            "apiKey": []
          }
        ],
        "deprecated": false
      }
    }
  }
}
''';

const String request_with_list_of_enum_in_parameter = '''
{
  "paths": {
    "/v3/order/{orderId}/state": {
      "put": {
        "tags": [
          "appie-order-controller-v-3"
        ],
        "summary": "Update state of an order.",
        "operationId": "changeOrderStateUsingPUT",
        "consumes": [
          "application/json"
        ],
        "produces": [
          "*/*"
        ],
        "parameters": [
          {
            "name": "orderId",
            "in": "path",
            "description": "Id of the order",
            "required": false,
            "type": "integer",
            "format": "int64"
          },
          {
            "in": "body",
            "name": "orderStateRequest",
            "description": "Order state",
            "required": false,
            "items": {
              "type": "string",
              "enum": [
                "SUBMITTED",
                "CANCELLED",
                "REOPENED",
                "RESET"
              ]
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "object"
            }
          },
          "201": {
            "description": "Created"
          },
          "401": {
            "description": "Unauthorized"
          },
          "403": {
            "description": "Forbidden"
          },
          "404": {
            "description": "Not Found"
          }
        },
        "security": [
          {
            "apiKey": []
          }
        ],
        "deprecated": false
      }
    }
  }
}
''';

const String request_with_array_string = '''
{
  "paths": {
    "/v1/{pboSortType}": {
      "get": {
        "tags": [
          "purchase-controller"
        ],
        "summary": "getPreviousPurchases",
        "operationId": "getPreviousPurchasesUsingGET",
        "produces": [
          "application/json"
        ],
        "parameters": [
          {
            "name": "applications",
            "in": "query",
            "description": "applications",
            "required": false,
            "type": "array",
            "items": {
              "type": "string"
            },
            "collectionFormat": "multi"
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "originalRef": "PagedResponseOfProductCard",
              "\$ref": "#/definitions/PagedResponseOfProductCard"
            }
          }
        }
      }
    }
  },
  "securityDefinitions": {
    "apiKey": {
      "type": "apiKey",
      "name": "x-authorization",
      "in": "header"
    }
  }
}
''';

const String request_with_array_order_summary = '''
{
  "paths": {
    "/v2/order/summaries": {
      "get": {
        "tags": [
          "appie-order-controller-v-2"
        ],
        "summary": "Get order summaries",
        "operationId": "retrieveOrderSummariesUsingGET",
        "produces": [
          "*/*"
        ],
        "parameters": [
          {
            "name": "x-application",
            "in": "header",
            "description": "x-application",
            "required": true,
            "type": "string"
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "array",
              "items": {
                "originalRef": "OrderSummary",
                "\$ref": "#/definitions/OrderSummary"
              }
            }
          },
          "401": {
            "description": "Unauthorized"
          },
          "403": {
            "description": "Forbidden"
          },
          "404": {
            "description": "Not Found"
          }
        },
        "security": [
          {
            "apiKey": []
          }
        ],
        "deprecated": false
      }
    }
  }
}
''';

const String request_with_list_string_return_type = '''
{
  "paths": {
    "/v1/suggestions": {
      "get": {
        "tags": [
          "search-controller-v-1"
        ],
        "summary": "product-search-suggestions",
        "description": "Search suggestions",
        "operationId": "findSuggestionsUsingGET",
        "produces": [
          "application/json"
        ],
        "parameters": [
          {
            "name": "amount",
            "in": "query",
            "description": "Amount of suggestions",
            "required": true,
            "type": "integer",
            "default": 10,
            "format": "int32",
            "allowEmptyValue": false
          },
          {
            "name": "query",
            "in": "query",
            "description": "Term to find suggestions for",
            "required": true,
            "type": "string",
            "allowEmptyValue": false
          },
          {
            "name": "x-application",
            "in": "header",
            "description": "x-application",
            "required": false,
            "type": "string"
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "array",
              "items": {
                "type": "string"
              }
            }
          },
          "401": {
            "description": "Unauthorized"
          },
          "403": {
            "description": "Forbidden"
          },
          "404": {
            "description": "Not Found"
          }
        },
        "security": [
          {
            "apiKey": []
          }
        ],
        "deprecated": false
      }
    }
  }
}
''';

const String schemas_responses_with_response = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Some service",
    "version": "1.0"
  },
  "components": {
    "responses": {
      "SpaResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "required": [
                "showPageAvailable"
              ],
              "properties": {
                "id": {
                  "type": "string",
                  "description": "Some description"
                },
                "showPageAvailable": {
                  "type": "boolean",
                  "description": "Flag indicating showPage availability"
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const String schemas_responses_with_response_and_schemas = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Some service",
    "version": "1.0"
  },
  "components": {
    "responses": {
      "SpaResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "required": [
                "showPageAvailable"
              ],
              "properties": {
                "id": {
                  "type": "string",
                  "description": "Some description"
                },
                "showPageAvailable": {
                  "type": "boolean",
                  "description": "Flag indicating showPage availability"
                }
              }
            }
          }
        }
      }
    },
    "schemas": {
      "SpaSchema": {
        "type": "object",
        "properties": {
          "id": {
            "type": "string",
            "description": "Some description"
          },
          "showPageAvailable": {
            "type": "boolean",
            "description": "Flag indicating showPage availability"
          }
        }
      }
    }
  }
}
''';

const String enum_as_definition_v2 = '''
{
  "openapi": "2.0.1",
  "definitions": {
      "SpaResponse": {
        "description": "Success",
        "enum": [
          "one",
          "two"
        ]
    }
  }
}
''';

const String schemas_with_enums_in_properties = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Some service",
    "version": "1.0"
  },
  "components": {
    "schemas": {
      "SpaSchema": {
        "type": "object",
        "properties": {
          "id": {
            "type": "string",
            "description": "Some description"
          },
          "showPageAvailable": {
            "type": "boolean",
            "description": "Flag indicating showPage availability"
          },
          "successValues": {
            "items": {
              "enum": [
                "one, two"
              ]
            }
          }
        }
      }
    },
    "responses": {
      "SpaResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "enum": [
                "one",
                "two"
              ]
            }
          }
        }
      },
      "SpaEnumResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "properties": {
                "failedValued": {
                  "items": {
                    "enum": [
                      "one",
                      "two"
                    ]
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const String request_with_return_type_injected = '''
{
  "paths": {
    "/model/items": {
      "get": {
        "summary": "Some test request",
        "operationId": "getModelItems",
        "parameters": [
          {
            "name": "testName",
            "in": "query",
            "description": "test name",
            "required": false,
            "type": "array",
            "items": {
              "type": "string"
            },
            "collectionFormat": "multi"
          }
        ],
        "responses": {
          "200": {
            "schema": {
              "type": "object",
              "properties": {
                "id": {
                  "type": "integer",
                  "format": "int64"
                },
                "petId": {
                  "type": "integer",
                  "format": "int64"
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const String request_with_ref_response = '''
{
  "components": {
    "schemes": {
      "MyCoolDefinition": {
        "type": "object",
        "properties": {
          "startTime": {
            "type": "string",
            "format": "date"
          },
          "endTime": {
            "type": "string",
            "format": "date"
          },
          "imageUrl": {
            "type": "string"
          }
        },
        "title": "MyCoolDefinition"
      }
    },
    "responses": {
      "SpaSingleResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "enum": [
                "one",
                "two"
              ]
            }
          }
        }
      },
      "SpaResponse": {
        "description": "Success",
        "content": {
          "application/json(1)": {
            "schema": {
              "enum": [
                "one",
                "two"
              ]
            }
          },
          "application/json(2)": {
            "schema": {
              "enum": [
                "one",
                "two"
              ]
            }
          }
        }
      }
    }
  },
  "paths": {
    "/model/items": {
      "get": {
        "summary": "Some test request",
        "operationId": "someOperationId",
        "parameters": [
          {
            "name": "headerParameter",
            "in": "header",
            "required": true,
            "type": "string"
          }
        ],
        "requestBody": {
          "content": {
            "application/json": {
              "schema": {
                "type": "array",
                "items": {
                  "\$ref": "#/components/responses/SpaResponse"
                }
              }
            }
          }
        },
        "responses": {
          "200": {
            "description": "OK",
            "\$ref": "#/responses/SpaResponse"
          }
        }
      }
    }
  }
}
''';



const String request_with_array_item_summary = '''
{
  "paths": {
    "/model/items": {
      "get": {
        "summary": "Some test request",
        "operationId": "getModelItems",
        "parameters": [
          {
            "name": "testName",
            "in": "query",
            "description": "test name",
            "required": false,
            "type": "array",
            "items": {
              "type": "string"
            },
            "collectionFormat": "multi"
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "array",
              "items": {
                "originalRef": "ItemSummary",
                "\$ref": "#/definitions/ItemSummary"
              }
            }
          }
        }
      }
    }
  }
}
''';

const String request_with_list_test_item_return_type = '''
{
  "paths": {
    "/model/items": {
      "get": {
        "summary": "Some test request",
        "operationId": "getModelItems",
        "parameters": [
          {
            "name": "testName",
            "in": "query",
            "description": "test name",
            "required": false,
            "type": "array",
            "items": {
              "type": "string"
            },
            "collectionFormat": "multi"
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "array",
              "items": {
                "originalRef": "TestItem",
                "\$ref": "#/definitions/TestItem"
              }
            }
          }
        }
      }
    }
  }
}
''';

const String request_with_object_ref_response = '''
{
  "paths": {
    "/model/items": {
      "get": {
        "summary": "Some test request",
        "operationId": "getModelItems",
        "parameters": [
          {
            "name": "testName",
            "in": "query",
            "description": "test name",
            "required": false,
            "type": "array",
            "items": {
              "type": "string"
            },
            "collectionFormat": "multi"
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "\$ref" : "MyObject"
            }
          }
        }
      }
    }
  }
}
''';

const String request_with_original_ref_return_type = '''
{
  "paths": {
    "/model/items": {
      "get": {
        "summary": "Some test request",
        "operationId": "getModelItems",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "originalRef": "TestItem"
            }
          }
        }
      }
    }
  }
}
''';

const String request_with_content_first_response_type = '''
{
  "paths": {
    "/model/items": {
      "get": {
        "summary": "Some test request",
        "operationId": "getModelItems",
        "responses": {
          "200": {
            "description": "OK",
            "content": {
              "applicacion/json": {
                "schema" : {
                  "type" : "String"
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const String request_with_content_first_response_ref = '''
{
  "paths": {
    "/model/items": {
      "get": {
        "summary": "Some test request",
        "operationId": "getModelItems",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type" : "testType",
              "items" : {
                "\$ref" : "#definitions/TestItem"
              }
            }
          }
        }
      }
    }
  }
}
''';

const String model_with_inheritance = '''
{
  "openapi": "3.0.0",
  "components": {
    "schemas": {
      "BasicErrorModel": {
        "type": "object",
        "required": [
          "message",
          "code"
        ],
        "properties": {
          "message": {
            "type": "string"
          },
          "code": {
            "type": "integer",
            "minimum": 100,
            "maximum": 600
          }
        }
      },
      "ExtendedErrorModel": {
        "allOf": [
          {
            "\$ref": "#/components/schemas/BasicErrorModel"
          },
          {
            "type": "object",
            "required": [
              "rootCause"
            ],
            "properties": {
              "rootCause": {
                "type": "string"
              }
            }
          }
        ]
      }
    }
  }
}
''';

const String model_with_enum = '''
{
   "openapi":"3.0.0",
   "components":{
      "schemas":{
         "BasicErrorModel":{
            "enum":[
               "message",
               "code"
            ]
         }
      }
   }
}
''';

const String model_with_inheritance_3_levels = '''
{
  "openapi": "3.0.0",
  "components": {
    "schemas": {
      "BasicErrorModel": {
        "type": "object",
        "required": [
          "message",
          "code"
        ],
        "properties": {
          "message": {
            "type": "string"
          },
          "code": {
            "type": "integer",
            "minimum": 100,
            "maximum": 600
          }
        }
      },
      "ExtendedErrorModel": {
        "allOf": [
          {
            "\$ref": "#/components/schemas/BasicErrorModel"
          },
          {
            "type": "object",
            "required": [
              "rootCause"
            ],
            "properties": {
              "rootCause": {
                "type": "string"
              }
            }
          }
        ]
      },
      "ErrorModelWithBadAllof": {
        "allOf": [
          {
            "\$ref": "#/components/schemas/NotExistingError"
          },
          {
            "type": "object",
            "required": [
              "rootCause"
            ]
          }
        ]
      },
      "MostExtendedErrorModel": {
        "allOf": [
          {
            "\$ref": "#/components/schemas/ExtendedErrorModel"
          },
          {
            "type": "object",
            "required": [
              "rootCause"
            ],
            "properties": {
              "phone": {
                "type": "string"
              }
            }
          }
        ]
      }
    }
  }
}
''';

const request_with_enum = '''
{
  "paths": {
    "/pets/{petId}/items": {
      "get": {
        "summary": "Some summary",
        "tags": [
          "Bookmarks"
        ],
        "parameters": [
          {
            "name": "contentType",
            "in": "query",
            "description": "content source type",
            "type": "string",
            "schema": {
              "enum": [
              "vod",
              "replay",
              "network-recording",
              "local-recording"
            ]
            }
          }
        ],
        "responses": {
          "200": {
            "description": "Bookmarks for given profile and content is returned.",
            "schema": {
              "\$ref": "#/definitions/Pet"
            }
          }
        }
      }
    }
  }
}
''';

const request_with_enum_request_body = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Test service",
    "version": "0.18.0"
  },
  "paths": {
    "/v3/customers/{customerId}/status": {
      "put": {
        "description": "Test request",
        "parameters": [
          {
            "name": "customerId",
            "in": "path",
            "description": "Test desc",
            "required": true,
            "schema": {
              "type": "string"
            }
          }
        ],
        "requestBody": {
          "description": "Test desc",
          "content": {
            "application/json": {
              "schema": {
                "\$ref": "#/components/schemas/CustomerStatus"
              }
            }
          },
          "required": true
        },
        "responses": {
          "204": {
            "description": "Customer Status was changed."
          }
        }
      }
    }
  },
  "components": {
    "schemas": {
      "CustomerStatus": {
        "title": "Customer Status",
        "type": "string",
        "enum": [
          "active",
          "inactive",
          "deleted"
        ]
      }
    }
  }
}
''';


final aaa = '''
{
  "openapi": "3.0.0",
  "info": {
    "title": "OESP-Perseus Auth",
    "description": "Updated OESP session/authentication API to serve for Perseus clients.",
    "version": "1.0.0"
  },
  "paths": {
    "/{countryCode}/{languageCode}/{deviceCode}/session": {
      "post": {
        "tags": [
          "Session WS"
        ],
        "summary": "Sign in and get session",
        "description": "Signs in using the supplied credentials, returning a session containing session details. Valid credentials are a combination username and password or the X-dev header.",
        "operationId": "signIn",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "extClientId",
            "schema": {
              "type": "string"
            },
            "required": false
          },
          {
            "in": "header",
            "name": "userAgent",
            "schema": {
              "type": "string"
            },
            "required": true
          },
          {
            "in": "header",
            "name": "trueClientIp",
            "schema": {
              "type": "string"
            },
            "required": true
          },
          {
            "in": "header",
            "name": "deviceId",
            "schema": {
              "type": "string"
            },
            "description": "the id of the device to be use in the silent authentication. The name of this header is set by configuration",
            "required": true
          },
          {
            "in": "query",
            "name": "token",
            "description": "if the device is supported, then token=true will include a refreshToken and refreshTokenExpiry in the response body. (true or false, false is the default value)",
            "schema": {
              "type": "boolean"
            },
            "required": false
          }
        ],
        "requestBody": {
          "description": "credentials",
          "content": {
            "application/json": {
              "schema": {
                "$ref": "#/components/schemas/Credentials"
              }
            }
          }
        },
        "responses": {
          "200": {
            "description": "Login successful",
            "headers": {
              "Set-Cookie": {
                "schema": {
                  "type": "string",
                  "example": "ACCESSTOKEN=abcde12345;",
                  "description": "New cookie, added for Perseus: ACCESSTOKEN"
                }
              }
            },
            "content": {
              "application/json": {
                "schema": {
                  "$ref": "#/components/schemas/WebSession"
                }
              }
            }
          },
          "400": {
            "description": "The request could not be performed due to a problem in the input.",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/invalidCredentials"
                    },
                    {
                      "$ref": "#/components/responses/accountLocked"
                    },
                    {
                      "$ref": "#/components/responses/noOrionEntitlement"
                    },
                    {
                      "$ref": "#/components/responses/X-dev"
                    }
                  ]
                }
              }
            }
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      },
      "get": {
        "tags": [
          "Session WS"
        ],
        "summary": "Returns the session for the supplied token.",
        "description": "This method should be called to ensure the session is kept alive within the timeToIdleSeconds as defined on the Session. This method supports If-Modified-Since request header. Resources may be invalidated when this resource's POST or PUT methods are invoked.",
        "operationId": "get",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-OESP-Token",
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-OESP-Username",
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-Client-Id",
            "required": false,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-Dr-Test",
            "required": false,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "query",
            "name": "uriInfo",
            "schema": {
              "type": "array",
              "items": {
                "type": "string"
              }
            }
          }
        ],
        "responses": {
          "200": {
            "description": "The request has succeeded.",
            "content": {
              "application/json": {
                "schema": {
                  "$ref": "#/components/schemas/WebSession"
                }
              }
            }
          },
          "400": {
            "description": "Invalid ID supplied",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/invalidCredentials"
                    },
                    {
                      "$ref": "#/components/responses/accountLocked"
                    },
                    {
                      "$ref": "#/components/responses/noOrionEntitlement"
                    },
                    {
                      "$ref": "#/components/responses/X-dev"
                    }
                  ]
                }
              }
            }
          },
          "403": {
            "description": "The user is not authorised to perform this request."
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      },
      "put": {
        "tags": [
          "Session WS"
        ],
        "summary": "Update an existing session",
        "description": "This method should be called when updating the user session. Fields currently supported for update - languageCode",
        "operationId": "updatePet",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-OESP-Token",
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-OESP-Username",
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-Client-Id",
            "required": false,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-Dr-Test",
            "required": false,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "query",
            "name": "uriInfo",
            "schema": {
              "type": "array",
              "items": {
                "type": "string"
              }
            }
          }
        ],
        "requestBody": {
          "description": "the session instance to update from",
          "content": {
            "application/json": {
              "schema": {
                "$ref": "#/components/schemas/WebSession"
              }
            }
          }
        },
        "responses": {
          "200": {
            "description": "The request has succeeded.",
            "content": {
              "application/json": {
                "schema": {
                  "$ref": "#/components/schemas/WebSession"
                }
              }
            }
          },
          "400": {
            "description": "Invalid ID supplied",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/invalidCredentials"
                    },
                    {
                      "$ref": "#/components/responses/accountLocked"
                    },
                    {
                      "$ref": "#/components/responses/noOrionEntitlement"
                    },
                    {
                      "$ref": "#/components/responses/X-dev"
                    }
                  ]
                }
              }
            }
          },
          "403": {
            "description": "The user is not authorised to perform this request."
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      },
      "delete": {
        "tags": [
          "Session WS"
        ],
        "summary": "Signs out for the supplied token.",
        "operationId": "signOut",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-OESP-Token",
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-OESP-Username",
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-Client-Id",
            "required": false,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "query",
            "name": "uriInfo",
            "schema": {
              "type": "array",
              "items": {
                "type": "string"
              }
            }
          }
        ],
        "responses": {
          "204": {
            "description": "The request was received and fulfilled successfully."
          },
          "400": {
            "description": "The request could not be performed due to a problem in the input.",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/invalidCredentials"
                    },
                    {
                      "$ref": "#/components/responses/accountLocked"
                    },
                    {
                      "$ref": "#/components/responses/noOrionEntitlement"
                    },
                    {
                      "$ref": "#/components/responses/X-dev"
                    }
                  ]
                }
              }
            }
          },
          "403": {
            "description": "The user is not authorised to perform this request."
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      }
    },
    "/{countryCode}/{languageCode}/{deviceCode}/session/update": {
      "post": {
        "tags": [
          "Session WS"
        ],
        "summary": "Updates the session with personalization Service values",
        "description": "This method should be called when updating the customer data to refresh the session data with it. Fields currently supported for update  - customer.replayTvOptedIn  - profileSettings.optInSettings.recommendations.status  - customer.sharedProfileId  - customer.profileIds",
        "operationId": "updatePersonalizeDetails",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "extClientId",
            "schema": {
              "type": "string"
            },
            "required": false
          },
          {
            "in": "header",
            "name": "userAgent",
            "schema": {
              "type": "string"
            },
            "required": true
          },
          {
            "in": "header",
            "name": "trueClientIp",
            "schema": {
              "type": "string"
            },
            "required": true
          },
          {
            "in": "header",
            "name": "deviceId",
            "schema": {
              "type": "string"
            },
            "description": "the id of the device to be use in the silent authentication. The name of this header is set by configuration",
            "required": true
          },
          {
            "in": "query",
            "name": "token",
            "description": "if the device is supported, then token=true will include a refreshToken and refreshTokenExpiry in the response body. (true or false, false is the default value)",
            "schema": {
              "type": "boolean"
            },
            "required": false
          }
        ],
        "requestBody": {
          "description": "credentials",
          "content": {
            "application/json": {
              "schema": {
                "$ref": "#/components/schemas/Credentials"
              }
            }
          }
        },
        "responses": {
          "200": {
            "description": "The request has succeeded.",
            "content": {
              "application/json": {
                "schema": {
                  "$ref": "#/components/schemas/WebSession"
                }
              }
            }
          },
          "400": {
            "description": "The request could not be performed due to a problem in the input.",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/invalidCredentials"
                    },
                    {
                      "$ref": "#/components/responses/accountLocked"
                    },
                    {
                      "$ref": "#/components/responses/noOrionEntitlement"
                    },
                    {
                      "$ref": "#/components/responses/X-dev"
                    }
                  ]
                }
              }
            }
          },
          "403": {
            "description": "The user is not authorised to perform this request."
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      }
    },
    "/{countryCode}/{languageCode}/{deviceCode}/authorization": {
      "get": {
        "tags": [
          "SsoAuthorization WS"
        ],
        "summary": "Return SSO Authorization details when SSO is active for the country.",
        "operationId": "getAuthorizationInfo",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "The request has succeeded.",
            "content": {
              "application/json": {
                "schema": {
                  "$ref": "#/components/schemas/AuthorizationDetails"
                }
              }
            }
          },
          "400": {
            "description": "The request could not be performed due to a problem in the input.",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/validationFailure"
                    },
                    {
                      "$ref": "#/components/responses/notAvailableForCountry"
                    },
                    {
                      "$ref": "#/components/responses/authorizationNotSupported"
                    }
                  ]
                }
              }
            }
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      },
      "post": {
        "tags": [
          "SsoAuthorization WS"
        ],
        "summary": "Return SSO Authorization details when SSO is active for the country.",
        "operationId": "authorize",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          }
        ],
        "requestBody": {
          "description": "credentials",
          "content": {
            "application/json": {
              "schema": {
                "$ref": "#/components/schemas/Credentials"
              }
            }
          }
        },
        "responses": {
          "200": {
            "description": "The request has succeeded.",
            "content": {
              "application/json": {
                "schema": {
                  "$ref": "#/components/schemas/AuthorizationResponse"
                }
              }
            }
          },
          "400": {
            "description": "The request could not be performed due to a problem in the input.",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/validationFailure"
                    },
                    {
                      "$ref": "#/components/responses/notAvailableForCountry"
                    },
                    {
                      "$ref": "#/components/responses/authorizationNotSupported"
                    }
                  ]
                }
              }
            }
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      }
    },
    "/{countryCode}/{languageCode}/{deviceCode}/authorization/silentstb": {
      "post": {
        "tags": [
          "SsoAuthorization WS"
        ],
        "summary": "Return a SSO response for a Set Top Box (STB) login.",
        "operationId": "stbAuthorize",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-OESP-Token",
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "header",
            "name": "X-OESP-Username",
            "schema": {
              "type": "string"
            }
          }
        ],
        "requestBody": {
          "description": "credentials",
          "content": {
            "application/json": {
              "schema": {
                "$ref": "#/components/schemas/StbAuthenticationRequest"
              }
            }
          }
        },
        "responses": {
          "200": {
            "description": "The request has succeeded.",
            "content": {
              "application/json": {
                "schema": {
                  "$ref": "#/components/schemas/AuthorizationResponse"
                }
              }
            }
          },
          "400": {
            "description": "The request could not be performed due to a problem in the input.",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/validationFailure"
                    },
                    {
                      "$ref": "#/components/responses/notAvailableForCountry"
                    },
                    {
                      "$ref": "#/components/responses/authorizationNotSupported"
                    }
                  ]
                }
              }
            }
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      }
    },
    "/{countryCode}/{languageCode}/{deviceCode}/authorization/device": {
      "post": {
        "tags": [
          "SsoAuthorization WS"
        ],
        "summary": "Request an authorization token to allow a device (such as a Chromecast) to play a stream.",
        "operationId": "device",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          }
        ],
        "requestBody": {
          "description": "credentials",
          "content": {
            "application/json": {
              "schema": {
                "$ref": "#/components/schemas/DeviceAuthorizationRequest"
              }
            }
          }
        },
        "responses": {
          "200": {
            "description": "The request has succeeded.",
            "content": {
              "application/json": {
                "schema": {
                  "$ref": "#/components/schemas/DeviceAuthorizationResponse"
                }
              }
            }
          },
          "400": {
            "description": "The request could not be performed due to a problem in the input.",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/validationFailure"
                    },
                    {
                      "$ref": "#/components/responses/notAvailableForCountry"
                    },
                    {
                      "$ref": "#/components/responses/authorizationNotSupported"
                    }
                  ]
                }
              }
            }
          },
          "403": {
            "description": "The user is not authorised to perform this request."
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      }
    },
    "/{countryCode}/{languageCode}/{deviceCode}/authorization/device/refreshtoken/{deviceId}/{authenticationToken}": {
      "get": {
        "tags": [
          "SsoAuthorization WS"
        ],
        "summary": "Returns the session with the refresh token for the supplied token.",
        "operationId": "deviceAuthorizeRefreshToken",
        "parameters": [
          {
            "in": "path",
            "name": "countryCode",
            "description": "the country code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "languageCode",
            "description": "the language code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceCode",
            "description": "the device code",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "deviceId",
            "description": "the device id for authorization token",
            "required": true,
            "schema": {
              "type": "string"
            }
          },
          {
            "in": "path",
            "name": "authenticationToken",
            "description": "the authentication token",
            "required": true,
            "schema": {
              "type": "string"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "The request has succeeded.",
            "content": {
              "application/json": {
                "schema": {
                  "$ref": "#/components/schemas/AuthorizationResponse"
                }
              }
            }
          },
          "400": {
            "description": "The request could not be performed due to a problem in the input.",
            "content": {
              "application/json": {
                "schema": {
                  "oneOf": [
                    {
                      "$ref": "#/components/responses/validationFailure"
                    },
                    {
                      "$ref": "#/components/responses/notAvailableForCountry"
                    }
                  ]
                }
              }
            }
          },
          "404": {
            "description": "The request could not be performed because the item being requested does not exist."
          }
        }
      }
    }
  },
  "components": {
    "schemas": {
      "Credentials": {
        "type": "object",
        "properties": {
          "username": {
            "type": "string"
          },
          "password": {
            "type": "string"
          },
          "refreshToken": {
            "type": "string"
          },
          "authorizationGrant": {
            "$ref": "#/components/schemas/ssoCredentials"
          }
        }
      },
      "ssoCredentials": {
        "type": "object",
        "properties": {
          "authorizationCode": {
            "type": "string"
          },
          "state": {
            "type": "string"
          },
          "validityToken": {
            "type": "string"
          }
        },
        "xml": {
          "name": "authorizationGrant"
        }
      },
      "WebSession": {
        "type": "object",
        "properties": {
          "oespToken": {
            "type": "string"
          },
          "accessToken": {
            "type": "string",
            "description": "New field, added for Perseus. Equals to oespToken."
          },
          "username": {
            "type": "string"
          },
          "locationId": {
            "type": "string"
          },
          "timeToIdleSeconds": {
            "type": "integer",
            "format": "int32"
          },
          "householdId": {
            "type": "string",
            "description": "New field,  added for Perseus. Equals to /customer/householdId."
          },
          "customer": {
            "type": "object",
            "properties": {
              "givenName": {
                "type": "string"
              },
              "familyName": {
                "type": "string"
              },
              "countryCode": {
                "type": "string"
              },
              "gender": {
                "type": "string"
              },
              "segmentAsNdh": {
                "type": "boolean"
              },
              "status": {
                "type": "array",
                "items": {
                  "type": "string"
                }
              },
              "smartCardId": {
                "type": "string"
              },
              "physicalDeviceId": {
                "type": "string"
              },
              "stbType": {
                "type": "string"
              },
              "networkDvrAvailable": {
                "type": "boolean"
              },
              "localDvrAvailable": {
                "type": "boolean"
              },
              "householdId": {
                "type": "string"
              },
              "sharedProfileId": {
                "type": "string"
              },
              "replayTvEntitled": {
                "type": "boolean"
              },
              "replayTvAvailable": {
                "type": "boolean"
              },
              "replayTvMinimumBroadcastTime": {
                "type": "integer",
                "format": "int32"
              },
              "replayTvOptedIn": {
                "type": "boolean"
              },
              "offlineViewingEntitled": {
                "type": "boolean"
              },
              "profileIds": {
                "type": "array",
                "items": {
                  "type": "string"
                }
              },
              "oboProvisioned": {
                "type": "boolean"
              },
              "customerId": {
                "type": "string"
              },
              "purchaseEntitlementsToken": {
                "type": "string"
              }
            }
          },
          "canStream3G": {
            "type": "boolean"
          },
          "adultPinVerified": {
            "type": "boolean"
          },
          "parentalPinVerified": {
            "type": "boolean"
          },
          "profilePinVerified": {
            "type": "boolean"
          },
          "profileCredentialVerified": {
            "type": "boolean"
          },
          "hasAdultCredential": {
            "type": "boolean"
          },
          "profileSettings": {
            "type": "object",
            "properties": {
              "pinSettings": {
                "type": "object",
                "properties": {
                  "isDefault": {
                    "type": "boolean"
                  }
                }
              },
              "parentalSettings": {
                "type": "object",
                "properties": {
                  "unrestrictedContentRatingCodes": {
                    "type": "array",
                    "items": {
                      "type": "string"
                    }
                  },
                  "isDefault": {
                    "type": "boolean"
                  }
                }
              },
              "purchaseSettings": {
                "type": "object",
                "properties": {
                  "restricted": {
                    "type": "boolean"
                  },
                  "isDefault": {
                    "type": "boolean"
                  }
                }
              },
              "termsSettings": {
                "type": "object",
                "properties": {
                  "version": {
                    "type": "string"
                  }
                }
              },
              "optInSettings": {
                "type": "object",
                "properties": {
                  "sko": {
                    "type": "object",
                    "properties": {
                      "status": {
                        "type": "string"
                      },
                      "lastUpdated": {
                        "type": "integer",
                        "format": "int64"
                      },
                      "version": {
                        "type": "string"
                      }
                    }
                  },
                  "recommendations": {
                    "type": "object",
                    "properties": {
                      "status": {
                        "type": "string"
                      },
                      "lastUpdated": {
                        "type": "integer",
                        "format": "int64"
                      }
                    }
                  }
                }
              }
            }
          },
          "entitlements": {
            "type": "array",
            "items": {
              "type": "string"
            }
          },
          "rbEntitlements": {
            "type": "array",
            "items": {
              "type": "string"
            }
          },
          "trackingId": {
            "type": "string"
          },
          "refreshToken": {
            "type": "string"
          },
          "homeScreenHint": {
            "type": "string"
          },
          "refreshTokenExpiry": {
            "type": "integer",
            "format": "int32"
          }
        }
      },
      "loginError": {
        "type": "array",
        "items": {
          "type": "object",
          "properties": {
            "type": {
              "type": "string",
              "example": "state"
            },
            "code": {
              "type": "string",
              "example": "invalidCredentials"
            },
            "reason": {
              "type": "string",
              "example": "invalid"
            }
          }
        }
      },
      "AuthorizationDetails": {
        "type": "object",
        "properties": {
          "resetParentalPin": {
            "description": "Since v2",
            "type": "object",
            "properties": {
              "authorizationUri": {
                "type": "string"
              },
              "redirectUri": {
                "type": "string"
              },
              "state": {
                "type": "string"
              },
              "validityToken": {
                "type": "string"
              }
            }
          },
          "session": {
            "description": "Since v2",
            "type": "object",
            "properties": {
              "deleteSessionUri": {
                "type": "string"
              },
              "redirectUri": {
                "type": "string"
              },
              "state": {
                "type": "string"
              },
              "authorizationUri": {
                "type": "string"
              },
              "validityToken": {
                "type": "string"
              }
            }
          },
          "redirectUri": {
            "description": "Until v1 (api)",
            "type": "string"
          },
          "authorizationUri": {
            "description": "Until v1 (api)",
            "type": "string"
          },
          "state": {
            "description": "Until v1 (api)",
            "type": "string"
          },
          "deleteSessionUri": {
            "description": "Until v1 (api)",
            "type": "string"
          },
          "validityToken": {
            "description": "Until v1 (api)",
            "type": "string"
          }
        }
      },
      "AuthorizationResponse": {
        "type": "object",
        "description": "an authorization details with customer id and refresh token",
        "properties": {
          "username": {
            "type": "string"
          },
          "refreshToken": {
            "type": "string"
          }
        }
      },
      "StbAuthenticationRequest": {
        "type": "object",
        "description": "request with authentication token",
        "properties": {
          "authenticationToken": {
            "type": "string"
          }
        }
      },
      "DeviceAuthorizationRequest": {
        "type": "object",
        "description": "request with device identifier",
        "properties": {
          "deviceId": {
            "type": "string"
          }
        }
      },
      "DeviceAuthorizationResponse": {
        "type": "object",
        "description": "device authorization details",
        "properties": {
          "authenticationToken": {
            "type": "string"
          }
        }
      }
    },
    "responses": {
      "validationFailure": {
        "description": "For a HTTP 400 response code indicating that the client had made a bad request, the body contains a JSON structure to detail why the request failed validation and the reason. The JSON format of the response is an array of objects, each of which has a type, code and reason. The allowed values for these are type - used to denote the main type of validation failure. Allowed values are binding - when there is a failure binding the request body to the api that cannot be specifically attributed to a particular field pathParam - when there is a failure with a particular path parameter queryParam - when there is a failure with a particular query parameter requestBody - when there is a failure with the request body state - when there is a failure due to some state specific to the endpoint code - used to denote the cause of the validation failure with respect to the type. For the above types binding - the code contains an indicator to the field in error, or is empty if unable to determine this pathParam - the code contains the name of the path parameter that caused the failure queryParam - the code contains the name of the query parameter that caused the failure requestBody - the code contains the object path to the offending property state - the code is an endpoint specific code that is documented in that endpoint's api documentation reason - used to denote the condition in which the validation failure occurred with respect to the type and code. Allowed values are invalid - used to denote that the failure is due to an invalid condition, e.g. a query parameter or request body property that is not in the correct format mandatory - used to denote that the failure is due to a mandatory condition, e.g. a query parameter or request body property that must be supplied prohibited - used to denote that the failure is due to a prohibited condition, e.g. a query parameter or request body property that is not allowed mutuallyExclusive - used to denote that the failure is due to a mutually exclusive condition, e.g. two query parameters that are not allowed together",
        "content": {
          "application/json": {
            "schema": {
              "$ref": "#/components/schemas/loginError"
            }
          }
        }
      },
      "invalidCredentials": {
        "description": "if the user credentials are invalid.",
        "content": {
          "application/json": {
            "schema": {
              "$ref": "#/components/schemas/loginError"
            }
          }
        }
      },
      "accountLocked": {
        "description": "if the user account is locked.",
        "content": {
          "application/json": {
            "schema": {
              "$ref": "#/components/schemas/loginError"
            }
          }
        }
      },
      "noOrionEntitlement": {
        "description": "if the user is required to have signed up for 'Orion' as a distinct product entitlement, but either has not, or has subsequently opted out of the 'Orion' product.",
        "content": {
          "application/json": {
            "schema": {
              "$ref": "#/components/schemas/loginError"
            }
          }
        }
      },
      "X-dev": {
        "description": "if the request does not include the device ID header."
      },
      "notAvailableForCountry": {
        "description": "A 400 Bad Request response can also be caused by a particular endpoint being unavailable for the Country."
      },
      "authorizationNotSupported": {
        "description": "if country has not SSO activated.",
        "content": {
          "application/json": {
            "schema": {
              "$ref": "#/components/schemas/loginError"
            }
          }
        }
      }
    }
  }
}
''';